# Generated by roxygen2: do not edit by hand

export(Document)
export(Element)
export(Stack)
export(Text)
export(isRc)
export(parse.xmlfile)
export(parse.xmlstring)
export(xmlrToDataFrame)
exportClasses(AbstractClass)
exportClasses(Content)
exportClasses(Document)
exportClasses(Element)
exportClasses(Stack)
exportClasses(Text)
import(methods)
